<?php

/**
  ReduxFramework Sample Config File
  For full documentation, please visit: https://docs.reduxframework.com
 * */

if (!class_exists('admin_folder_Redux_Framework_config')) {

    class admin_folder_Redux_Framework_config {

        public $args        = array ();
        public $sections    = array ();
        public $theme;
        public $ReduxFramework;

        public function __construct() {

            if (!class_exists('ReduxFramework')) {
                return;
            }

            // This is needed. Bah WordPress bugs.  ;)
            if ( true == Redux_Helpers::isTheme( __FILE__ ) ) {
                $this->initSettings();
            } else {
                add_action('plugins_loaded', array ($this, 'initSettings'), 10);
            }

        }

        public function initSettings() {

            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();

            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }

            // If Redux is running as a plugin, this will remove the demo notice and links
            add_action( 'redux/loaded', array ( $this, 'remove_demo' ) );
            
            // Function to test the compiler hook and demo CSS output.
            // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
            //add_filter('redux/options/'.$this->args['opt_name'].'/compiler', array ( $this, 'compiler_action' ), 10, 2);
            
            // Change the arguments after they've been declared, but before the panel is created
            //add_filter('redux/options/'.$this->args['opt_name'].'/args', array ( $this, 'change_arguments' ) );
            
            // Change the default value of a field after it's been set, but before it's been useds
            //add_filter('redux/options/'.$this->args['opt_name'].'/defaults', array ( $this,'change_defaults' ) );
            
            // Dynamically add a section. Can be also used to modify sections/fields
            //add_filter('redux/options/' . $this->args['opt_name'] . '/sections', array ($this, 'dynamic_section'));

            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

        /**

          This is a test function that will let you see when the compiler hook occurs.
          It only runs if a field	set with compiler=>true is changed.

         * */
        function compiler_action($options, $css) {
            echo '<h1>The compiler hook has run!';
            print_r($options); //Option values
            print_r($css); // Compiler selector CSS values  compiler => array ( CSS SELECTORS )

            
              // Demo of how to use the dynamic CSS and write your own static CSS file
              $filename = dirname(__FILE__) . '/style' . '.css';
              global $wp_filesystem;
              if( empty( $wp_filesystem ) ) {
                require_once( ABSPATH .'/wp-admin/includes/file.php' );
              WP_Filesystem();
              }

              if( $wp_filesystem ) {
                $wp_filesystem->put_contents(
                    $filename,
                    $css,
                    FS_CHMOD_FILE // predefined mode settings for WP files
                );
              }
             
        }

        /**

          Custom function for filtering the sections array . Good for child themes to override or add to the sections.
          Simply include this function in the child themes functions.php file.

          NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
          so you must use get_template_directory_uri() if you want to use any of the built in icons

         * */
        function dynamic_section($sections) {
            //$sections = array ();
            $sections[] = array (
                'title' => __('Section via hook', 'inovate'),
                'desc' => __('<p class="description">This is a section created by adding a filter to the sections array . Can be used by child themes to add/remove sections from the options.</p>', 'inovate'),
                'icon' => 'el-icon-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array ()
            );

            return $sections;
        }

        /**

          Filter hook for filtering the args. Good for child themes to override or add to the args array . Can also be used in other functions.

         * */
        function change_arguments($args) {
            //$args['dev_mode'] = true;

            return $args;
        }

        /**

          Filter hook for filtering the default value of any given field. Very useful in development mode.

         * */
        function change_defaults($defaults) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }

        // Remove the demo link and the notice of integrated demo from the redux-framework plugin
        function remove_demo() {

            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if (class_exists('ReduxFrameworkPlugin')) {
                remove_filter('plugin_row_meta', array (ReduxFrameworkPlugin::instance(), 'plugin_metalinks'), null, 2);

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action('admin_notices', array (ReduxFrameworkPlugin::instance(), 'admin_notices'));
            }
        }

        public function setSections() {

            /**
              Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
             * */
            // Background Patterns Reader
            $sample_patterns_path   = ReduxFramework::$_dir . '../sample/patterns/';
            $sample_patterns_url    = ReduxFramework::$_url . '../sample/patterns/';
            $sample_patterns        = array ();

            if (is_dir($sample_patterns_path)) :

                if ($sample_patterns_dir = opendir($sample_patterns_path)) :
                    $sample_patterns = array ();

                    while (( $sample_patterns_file = readdir($sample_patterns_dir) ) !== false) {

                        if (stristr($sample_patterns_file, '.png') !== false || stristr($sample_patterns_file, '.jpg') !== false) {
                            $name = explode('.', $sample_patterns_file);
                            $name = str_replace('.' . end($name), '', $sample_patterns_file);
                            $sample_patterns[]  = array ('alt' => $name, 'img' => $sample_patterns_url . $sample_patterns_file);
                        }
                    }
                endif;
            endif;

            ob_start();

            $ct             = wp_get_theme();
            $this->theme    = $ct;
            $item_name      = $this->theme->get('Name');
            $tags           = $this->theme->Tags;
            $screenshot     = $this->theme->get_screenshot();
            $class          = $screenshot ? 'has-screenshot' : '';

            $customize_title = sprintf(__('Customize &#8220;%s&#8221;', 'inovate'), $this->theme->display('Name'));
            
            ?>
            <div id="current-theme" class="<?php echo esc_attr($class); ?>">
            <?php if ($screenshot) : ?>
                <?php if (current_user_can('edit_theme_options')) : ?>
                        <a href="<?php echo wp_customize_url(); ?>" class="load-customize hide-if-no-customize" title="<?php echo esc_attr($customize_title); ?>">
                            <img src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview'); ?>" />
                        </a>
                <?php endif; ?>
                    <img class="hide-if-customize" src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e('Current theme preview'); ?>" />
                <?php endif; ?>

                <h4><?php echo $this->theme->display('Name'); ?></h4>

                <div>
                    <ul class="theme-info">
                        <li><?php printf(__('By %s', 'inovate'), $this->theme->display('Author')); ?></li>
                        <li><?php printf(__('Version %s', 'inovate'), $this->theme->display('Version')); ?></li>
                        <li><?php echo '<strong>' . __('Tags', 'inovate') . ':</strong> '; ?><?php printf($this->theme->display('Tags')); ?></li>
                    </ul>
                    <p class="theme-description"><?php echo $this->theme->display('Description'); ?></p>
            <?php
            if ($this->theme->parent()) {
                printf(' <p class="howto">' . __('This <a href="%1$s">child theme</a> requires its parent theme, %2$s.') . '</p>', __('http://codex.wordpress.org/Child_Themes', 'inovate'), $this->theme->parent()->display('Name'));
            }
            ?>

                </div>
            </div>

            <?php
            $item_info = ob_get_contents();

            ob_end_clean();

            $sampleHTML = '';
            if (file_exists(dirname(__FILE__) . '/info-html.html')) {
                /** @global WP_Filesystem_Direct $wp_filesystem  */
                global $wp_filesystem;
                if (empty($wp_filesystem)) {
                    require_once(ABSPATH . '/wp-admin/includes/file.php');
                    WP_Filesystem();
                }
                $sampleHTML = $wp_filesystem->get_contents(dirname(__FILE__) . '/info-html.html');
            }
                       
             $this->sections[] = array (
                'title'     => __('Home Settings', 'inovate'),
                'icon'      => 'el-icon-home',
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array (
                	array (
                        'id'        => 'logo',
                        'type'      => 'media',
                        'title'     => __('Logo', 'inovate'),
                        'compiler'  => 'true',
                        'default'   => '',
                        'url'		=> true,
                        'mode'      => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'default'   =>array (
                        'url' 		=> '',
                        				),
                        'subtitle'  => __('Upload the logo you want for your header', 'inovate'),
                    ),
                    array (
                    	'id'		=> 'featured-home',
                    	'type'		=> 'checkbox',
                    	'title'		=> __('Featured Image on Post','inovate'),
                    	'subtitle'		=> __('Tick the box if you ant the featured Image to appear on the Post page','inovate'),
                    	'default'	=> '1',
                    )
                    
               )
            );
            
            $this->sections[] = array (
                'title'     => __('Layout Settings', 'inovate'),
                'icon'      => 'el-icon-th-large',
                'fields'	=> array (
                	array (
                		'id'		=> 'layout',
                		'type'		=> 'image_select',
                		'title'		=> __('Site Layout', 'inovate'),
                		'compiler'	=> true,
                		'default'	=> '1',
                		'desc'		=> __('Select the Layout for your website posts and pages','inovate'),
                		'options'	=> array (
                		'1'   => array (
                    		'alt' => 'Right Sidebar', 
                    		'img' => ReduxFramework::$_url . 'assets/img/2cr.png'),
                    	'2'   => array (
                    		'alt' => 'Left Sidebar', 
                    		'img' => ReduxFramework::$_url . 'assets/img/2cl.png'),
                    		)
                    	)
                    )                		
               );
               
               $this->sections[] = array(
                'title'     => __('Slider Settings', 'bose'),
                'icon'      => 'el-icon-picture',
                // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                'fields'    => array(
                		array(
	                        'id'        => 'slider-enable-on-home',
	                        'type'      => 'checkbox',
	                        'title'     => __('Enable Slider on Home', 'bose'),
	                        'subtitle'  => __('This will enable slider on both the front page, and homepage.', 'bose'),
	                        //'options' => array('on', 'off'),
	                        'default'   => false,
                        ),
                       
	                	array(
	                        'id'        => 'slider-main',
	                        'type'      => 'slides',
	                        'title'     => __('Slides Options', 'bose'),
	                        'subtitle'  => __('Maximum 5 slides with drag and drop sortings.', 'bose'),
	                        'desc'      => __('', 'bose'),
	                        'placeholder'   => array(
	                            'title'         => __('Slide Title', 'bose'),
	                            'url'           => __('URL you want to Link.', 'bose'),
	                        ),
	                    ),
                   ), 
             );
               
               $this->sections[] = array (
               	'title'		=> __('Showcase Settings','inovate'),
               	'icon'		=> 'el-icon-th',
               	'fields'	=> array (
               		array (
               			'id'		=> 'showcase',
               			'type'		=> 'checkbox',
               			'title'		=> __('Enable Showcase', 'inovate'),
               			'subtitle'	=> __('Tick the checkbox to enable Showcase on homepage.','inovate'),
               			'default'	=> '0',
               			),
               		array (
               			'id'		=> 'showcase-slide',
               			'type'		=> 'slides',
               			'title'		=> 'Showcase Items',
               			'subtitle'		=> __('Add the items to add to your showcase (only 3)','inovate')
               			)
               		)
               	);
               	
               	$this->sections[] = array (
               	 'title'	=> __('Social Settings','inovate'),
               	 'icon'		=> 'el-icon-share',
               	 'fields'	=> array (
               	 	array (
               	 		'id'		=> 'social',
               	 		'type'		=> 'checkbox',
               	 		'title'		=> __('Enable Social Icons','inovate'),
               	 		'subtitle'	=> __('Tick the checkbox to enable the social icons in the header','inovate'),
               	 		'default'	=> '0',
               	 	),
               	 	array (
               	 		'id'		=> 'icon',
               	 		'type'		=> 'select',
               	 		'title'		=> __('Social Icon Set','inovate'),
               	 		'subtitle'	=> __('Select which Icon Set to display.','inovate'),
               	 		'options'	=> array (
               	 			'def'		=> 'Default',
               	 			'glossy'	=> 'Glossy',
               	 			'soshion'	=> 'Soshions',
               	 			'picons'	=> 'Picons'
               	 			),
               	 	
               	 		'default'	=> 'picons',
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'facebook',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Facebook URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'twitter',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Twitter URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'google',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Google Plus URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'instagram',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Instagram URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'youtube',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Youtube URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'rss',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('RSS URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'mail',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Mail URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'pinterest',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Pinterest URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'vimeo',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Vimeo URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'stumbleupon',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('StumbleUpon URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'linkedin',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Linked In URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'flickr',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Flickr URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'vine',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Vine URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'vk',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('VKontakte URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'soundcloud',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('SoundCloud URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 ),
               	 	 array (
               	 	 	'id'		=> 'yelp',
               	 	 	'type'		=> 'text',
               	 	 	'title'		=> __('Yelp URL','inovate'),
               	 	 	'default'	=> __('#','inovate'),
               	 	 )   
               	 )
             );
        }

        /**

          All the possible arguments for Redux.
          For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments

         * */
        public function setArguments() {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $this->args = array (
                'opt_name' => 'opt_inovate',
                'display_name' => 'Inovate Options',
                'page_slug' => '_options',
                'page_title' => 'Inovate Options',
                'dev_mode' => '0',
                'update_notice' => '1',
                'intro_text' => '<p><strong>Welcome to the Options Panel of Inovate.</strong></p>',
                'footer_text' => '',
                'admin_bar' => '1',
                'menu_type' => 'submenu',
                'menu_title' => 'Inovate Options',
                'allow_sub_menu' => '1',
                'page_parent_post_type' => 'your_post_type',
                'customizer' => '1',
                'hints' => 
                array (
                  'icon' => 'el-icon-question-sign',
                  'icon_position' => 'right',
                  'icon_size' => 'normal',
                  'tip_style' => 
                  array (
                    'color' => 'light',
                  ),
                  'tip_position' => 
                  array (
                    'my' => 'top left',
                    'at' => 'bottom right',
                  ),
                  'tip_effect' => 
                  array (
                    'show' => 
                    array (
                      'duration' => '500',
                      'event' => 'mouseover',
                    ),
                    'hide' => 
                    array (
                      'duration' => '500',
                      'event' => 'mouseleave unfocus',
                    ),
                  ),
                ),
                'output' => '1',
                'output_tag' => '1',
                'compiler' => '1',
                'page_icon' => 'icon-themes',
                'page_permissions' => 'manage_options',
                'save_defaults' => '1',
                'show_import_export' => '0',
                'transient_time' => '3600',
                'network_sites' => '0',
              );

            /*
// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
            $this->args['share_icons'][] = array (
                'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
                'title' => 'Visit us on GitHub',
                'icon'  => 'el-icon-github'
                //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
            );
            $this->args['share_icons'][] = array (
                'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
                'title' => 'Like us on Facebook',
                'icon'  => 'el-icon-facebook'
            );
            $this->args['share_icons'][] = array (
                'url'   => 'http://twitter.com/reduxframework',
                'title' => 'Follow us on Twitter',
                'icon'  => 'el-icon-twitter'
            );
            $this->args['share_icons'][] = array (
                'url'   => 'http://www.linkedin.com/company/redux-framework',
                'title' => 'Find us on LinkedIn',
                'icon'  => 'el-icon-linkedin'
            );
*/

        }

    }
    
    global $reduxConfig;
    $reduxConfig = new admin_folder_Redux_Framework_config();
}

/**
  Custom function for the callback referenced above
 */
if (!function_exists('admin_folder_my_custom_field')):
    function admin_folder_my_custom_field($field, $value) {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
endif;

/**
  Custom function for the callback validation referenced above
 * */
if (!function_exists('admin_folder_validate_callback_function')):
    function admin_folder_validate_callback_function($field, $value, $existing_value) {
        $error = false;
        $value = 'just testing';

        /*
          do your validation

          if(something) {
            $value = $value;
          } elseif(something else) {
            $error = true;
            $value = $existing_value;
            $field['msg'] = 'your custom error message';
          }
         */

        $return['value'] = $value;
        if ($error == true) {
            $return['error'] = $field;
        }
        return $return;
    }
endif;
